# Soldering

## Helping hands

https://www.prusaprinters.org/prints/44064-clamping-helping-hand

# Sidewinder X2

**With metal heatbreak: 285°C**

https://3dprintbeginner.com/sidewinder-x2-custom-touchscreen-firmware/

https://3dprintbeginner.com/artillery-sidewinder-x2-upgrades/

## Firmwares

X2 <-- **using this one**
   : https://www.thingiverse.com/thing:5186707
	 
All (fr)
   : https://github.com/Dtcreation/Firmware-Molise-Artillery

All (fr)
  : https://www.lesimprimantes3d.fr/forum/topic/44697-tuto-comment-flasher-le-firmware-des-x2-genius-pro-hornet/page/13/?sortby=date#comments

## Done
https://www.thingiverse.com/thing:4799645

# MCU
## Tensorflow

https://www.hackster.io/boochowp/gesture-recognition-with-m5stack-tensorflow-lite-da212b

# Shops
- https://www.lay3rs-retail.nl

# Z-offset (probe)
```M851 X27.2500 Y-12.8000 Z-1.3000```

Z-1.4 => more "deep" (lower Z) than -1.3


# Next Printer
- sidewinder X2 (<400€)
- Flsun Super Racer (bowden)
- prusa XL 
- delta ?

# Elastic football table
https://www.prusaprinters.org/prints/74135-elastic-football

# Best websites

- https://cults3d.com/
- https://www.myminifactory.com/
- https://www.cgtrader.com/
- https://www.prusaprinters.org/
- https://pinshape.com/
- https://3dexport.com/
- https://www.youmagine.com/
- https://nasa3d.arc.nasa.gov/models/printable
- https://3dprint.nih.gov/
